*                          MICRON HSPICE MODEL
*
* Disclaimer:   This software code and all associated documentation, comments
*               or other information (collectively "Software") is provided 
*               "AS IS" without warranty of any kind. MICRON TECHNOLOGY, INC. 
*               ("MTI") EXPRESSLY DISCLAIMS ALL WARRANTIES EXPRESS OR IMPLIED,
*               INCLUDING BUT NOT LIMITED TO, NONINFRINGEMENT OF THIRD PARTY
*               RIGHTS, AND ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
*               FOR ANY PARTICULAR PURPOSE. MTI DOES NOT WARRANT THAT THE
*               SOFTWARE WILL MEET YOUR REQUIREMENTS, OR THAT THE OPERATION OF
*               THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE. FURTHERMORE,
*               MTI DOES NOT MAKE ANY REPRESENTATIONS REGARDING THE USE OR THE
*               RESULTS OF THE USE OF THE SOFTWARE IN TERMS OF ITS CORRECTNESS,
*               ACCURACY, RELIABILITY, OR OTHERWISE. THE ENTIRE RISK ARISING OUT
*               OF USE OR PERFORMANCE OF THE SOFTWARE REMAINS WITH YOU. IN NO
*               EVENT SHALL MTI, ITS AFFILIATED COMPANIES OR THEIR SUPPLIERS BE
*               LIABLE FOR ANY DIRECT, INDIRECT, CONSEQUENTIAL, INCIDENTAL, OR
*               SPECIAL DAMAGES (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS
*               OF PROFITS, BUSINESS INTERRUPTION, OR LOSS OF INFORMATION)
*               ARISING OUT OF YOUR USE OF OR INABILITY TO USE THE SOFTWARE,
*               EVEN IF MTI HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*               Because some jurisdictions prohibit the exclusion or limitation
*               of liability for consequential or incidental damages, the above
*               limitation may not apply to you.
* 
*               Copyright 2005 Micron Technology, Inc. All rights reserved.
*
************** 128Megx4, 64Megx8, 32Megx16 DDR2-667 & 800 SDRAM****************
**************** Example HSPICE setup for CLK/CLK# inputs**********************

***********************************************************
****             ___                                      *
****    CLK_OUT-/  +|-CLKPAD----\/\/\/--@@@@-----IN_PKG   *
****           {   -|-CLKPAD_--| R_pkg  L_pkg |           *
****   CLK_OUT_-\___|-RCVREN   |             ===C_pkg     *
****                           |              |           *
****                           |             GND          *
****                           |                          *
****                           -\/\/\/--@@@@-----INN_PKG  *
****                            Rn_pkg Ln_pkg |           *
****                                         ===Cn_pkg    *
****                                          |           *
****                                         GND          *
***********************************************************

**** This netlist is for the x4, x8, x16 512Mb DDR2-667 & 800 SDRAM ************
**** The input signals are IN_PKG and INN_PKG.
**** The positive output of the input receiver circuit is the node CLK_OUT.
**** The negative output of the input receiver circuit is the node CLK_OUT_.
**** To account for package parasitics correlative impedance values
**** (netlist elements r_pkg,l_pkg,c_pkg for CLKPAD, rn_pkg,ln_pkg,cn_pkg
**** for CLKPAD_) have been attached to the PAD nodes.

**** The .LIB statement selects the following modes:
****    typ - Fast N, Fast P, Typical die capacitance
****    slow - Fast N, Fast P, Maximum die capacitance
****    fast - Fast N, Fast P, Minimum die capacitance
**** Only the fast transistor corner is valid for DDR2-667 and 800 operation

**** To run this simulation, the files "model_800.cnr" and "u37y_clkbuff.inc" are
**** required to be in the same directory as this netlist.
**** Temperature settings are: Typical 40C, Slow 100C, Fast 0C

.OPTIONS ACCT OPTS NOPAGE POST
.OPTIONS METHOD=GEAR
.OPTIONS SEARCH=' '  $This option must be present for decryption to work

.TRAN 0.01ns 10.0ns
**The temperature is for the slow case
.TEMP 100
.LIB "model_800.cnr" slow

**** Input signals and power supplies setup
**** Note: vccp is a regulated internal voltage
**** Match up typ, min, or max voltages for corner sims
.PARAM  vcc_typ   = 1.800V
.PARAM  vcc_min   = 1.700V
.PARAM  vcc_max   = 1.900V

.PARAM  vccp_typ  = 3.30V
.PARAM  vccp_min  = 3.20V
.PARAM  vccp_max  = 3.40V

.PARAM  gnd       = 0.0V
********************************************************************************
.PARAM  vcc       = vcc_min
.PARAM  vccp      = vccp_min
******************************************************************************** 
Vvcc    vcc   0  DC = vcc
Vvccp   vccp  0  DC = vccp

Ven  rcvr_en  0  DC = vcc
**Active high receiver enable

Vin   in_pkg  0  PULSE gnd vcc 100ps 200ps 200ps 1.30ns 3.00ns
**Vin toggles the CLK at 333MHz
Vin_  inn_pkg 0  PULSE vcc gnd 100ps 200ps 200ps 1.30ns 3.00ns

* top cell:  clk
* *********************************************
* Output load circuits:
xi0 CLK_PAD CLK_PAD_ RCVR_EN CLK_OUT CLK_OUT_ gnd vcc vccp u37y_clkbuff

* Refer to the IBIS model for specific package parasitic values.
r_pkg CLK_PAD net1 R=159e-3
l_pkg net1 in_pkg L=2.47e-9
c_pkg in_pkg gnd c=170e-15
rn_pkg CLK_PAD_ net2 R=159e-3
ln_pkg net2 inn_pkg L=2.47e-9
cn_pkg inn_pkg gnd c=170e-15


.alter typ
.PARAM  vcc         = vcc_typ
.PARAM  vccp        = vccp_typ
.temp 40
.LIB "model_800.cnr" typ

.alter fast
.PARAM  vcc         = vcc_max
.PARAM  vccp        = vccp_max
.temp 0
.LIB "model_800.cnr" fast

.END
