*                          MICRON HSPICE MODEL
*
* Disclaimer:   This software code and all associated documentation, comments
*               or other information (collectively "Software") is provided 
*               "AS IS" without warranty of any kind. MICRON TECHNOLOGY, INC. 
*               ("MTI") EXPRESSLY DISCLAIMS ALL WARRANTIES EXPRESS OR IMPLIED,
*               INCLUDING BUT NOT LIMITED TO, NONINFRINGEMENT OF THIRD PARTY
*               RIGHTS, AND ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
*               FOR ANY PARTICULAR PURPOSE. MTI DOES NOT WARRANT THAT THE
*               SOFTWARE WILL MEET YOUR REQUIREMENTS, OR THAT THE OPERATION OF
*               THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE. FURTHERMORE,
*               MTI DOES NOT MAKE ANY REPRESENTATIONS REGARDING THE USE OR THE
*               RESULTS OF THE USE OF THE SOFTWARE IN TERMS OF ITS CORRECTNESS,
*               ACCURACY, RELIABILITY, OR OTHERWISE. THE ENTIRE RISK ARISING OUT
*               OF USE OR PERFORMANCE OF THE SOFTWARE REMAINS WITH YOU. IN NO
*               EVENT SHALL MTI, ITS AFFILIATED COMPANIES OR THEIR SUPPLIERS BE
*               LIABLE FOR ANY DIRECT, INDIRECT, CONSEQUENTIAL, INCIDENTAL, OR
*               SPECIAL DAMAGES (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS
*               OF PROFITS, BUSINESS INTERRUPTION, OR LOSS OF INFORMATION)
*               ARISING OUT OF YOUR USE OF OR INABILITY TO USE THE SOFTWARE,
*               EVEN IF MTI HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*               Because some jurisdictions prohibit the exclusion or limitation
*               of liability for consequential or incidental damages, the above
*               limitation may not apply to you.
* 
*               Copyright 2005 Micron Technology, Inc. All rights reserved.
*
************** 128Megx4, 64Megx8, 32Megx16 DDR2-667 & 800 SDRAM ***************
********Example HSPICE setup file for DQs and DQS (when DQS# is disabled)******

***********************************************************
****           ____                                       *
****      IN--|    \                                      *
****          |     }------PAD--\/\/\/--@@@@--|--PKG_OUT  *
****   ENOUT--|____/    |        R_pkg  L_pkg |           *
****                    |                    ===C_pkg     *
****             ___    |                     |           *
****            /  +|---|                    GND          *
**** RCVR_OUT--{   -|-----VREF                            *
****            \___|-(ENOUT#)                            *
***********************************************************

**** This netlist is for the x4, x8, x16 512Mb DDR2-667 & 800 SDRAM ************
**** The input signals are IN (input signal) and ENOUT (output enable signal).
**** The I/O data is available on the signal PAD.
**** The output of the input receiver circuit is the node RCVR_OUT.
**** To account for package parasitics correlative impedance values
**** (netlist elements R_pkg, L_pkg, C_pkg) have been attached to the PAD
**** node.  The package output is on the signal PKG_OUT.

**** NOTE: This spice file is not designed to match datasheet timing numbers.
****       Delay times are smaller than those given in the data sheets.

**** The .LIB statement selects the following modes:
****    typ - Fast N, Fast P, Typical die capacitance
****    slow - Fast N, Fast P, Maximum die capacitance
****    fast - Fast N, Fast P, Minimum die capacitance
**** Only the fast transistor corner is valid for DDR2-667 & 800 operation

**** To run this simulation, the files "model_800.cnr" and "u37y_dqbuff.inc" are
**** required to be in the same directory as this netlist.
**** Temperature settings are: Typical 40C, Slow 100C, Fast 0C

.OPTIONS ACCT OPTS NOPAGE POST 
.OPTIONS METHOD=GEAR
.OPTIONS SEARCH=' '  $This option must be present for decryption to work

.TRAN 0.02ns 10.0ns
**The temperature is for the slow case
.TEMP 100
.LIB "model_800.cnr" slow

**** Input signals and power supplies setup
**** Note: vccp is a regulated internal voltage
**** Match up typ, min, or max voltages for corner sims
.PARAM  vccq_typ  = 1.800V
.PARAM  vccq_min  = 1.700V
.PARAM  vccq_max  = 1.900V

.PARAM  vcc_typ   = 1.800V
.PARAM  vcc_min   = 1.700V
.PARAM  vcc_max   = 1.900V

.PARAM  vccp_typ  = 3.30V
.PARAM  vccp_min  = 3.20V
.PARAM  vccp_max  = 3.40V

.PARAM  gnd       = 0.0V
.PARAM  vssq      = 0.0V
********************************************************************************
.PARAM  vccq      = vccq_min
.PARAM  vcc       = vcc_min
.PARAM  vccp      = vccp_min
******************************************************************************** 
Vvccq   vccq  0  DC = vccq
Vvcc    vcc   0  DC = vcc
Vvccp   vccp  0  DC = vccp
Vvssq   vssq  0  DC = vssq
Vref    vref  0  DC = 'vccq/2' 
Vvtt    vtt   0  DC = 'vccq/2' 

Vdrv full_drv  0  DC = vcc  $vcc = 100%, gnd = 60%
**The fulldrv node selects between Full and Reduced output drive strengths.

*****************************************************************************
**On-Die Termination is controlled like the Extended Mode Register settings**
*****************************************************************************
**Bit Settings: EMR Bit 6     EMR Bit 2     Function    **
**                  0             0         disabled    **
**                  0             1         75 ohm ODT  **
**                  1             0         150 ohm ODT **
**                  1             1         50 ohm ODT  **
**********************************************************
Vodt_emr6  odt_emr6 0  DC = gnd  $ see table above for settings
Vodt_emr2  odt_emr2 0  DC = gnd  $ 0 = gnd, 1 = vcc
**********************************************************
Vodt_en    odt_en   0  DC = gnd
*Active high ODT enable, set odt_en to vcc/gnd and set the EMR bits to toggle ODT on/off

Ven     enout 0  DC = vcc
**Active high for output, Active low for input

Vin   in  0  PULSE gnd vccq 100ps 100ps 100ps 1.40ns 3.00ns
**Vin toggles the DQ at 667Mb/s
*Vwrite     pkg_out    0  PULSE gnd vccq 100ps 100ps 100ps 1.40ns 3.00ns

* top cell:  dq
* *********************************************
* Output load circuits:
xi0 ENOUT FULL_DRV IN ODT_EMR2 ODT_EMR6 ODT_EN VREF PAD RCVR_OUT gnd vcc vccp vccq vssq u37y_dqbuff

* Refer to the IBIS model for specific package parasitic values.
r_pkg pad net1 R=159e-3
l_pkg net1 pkg_out L=2.47e-9
c_pkg pkg_out gnd c=170e-15

rload pkg_out vtt 25

.alter typ
.PARAM  vccq        = vccq_typ
.PARAM  vcc         = vcc_typ
.PARAM  vccp        = vccp_typ
.temp 40
.LIB "model_800.cnr" typ

.alter fast
.PARAM  vccq        = vccq_max
.PARAM  vcc         = vcc_max
.PARAM  vccp        = vccp_max
.temp 0
.LIB "model_800.cnr" fast

.END
